@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0205';
+our $VERSION = '0.0206';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -125,7 +125,7 @@ sub generate {
     }
 
     if ($self->guitar) {
-        @fixed = map { $_ < 40 ? $_ + 12 : $_ } @fixed;
+        @fixed = sort { $a <=> $b } map { $_ < 40 ? $_ + 12 : $_ } @fixed;
     }
 
     # DEBUGGING:
@@ -169,7 +169,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0205
+version 0.0206
 
 =head1 SYNOPSIS
 
